@@ -113,7 +113,7 @@ extensions = [
     'sunpy.util.sphinx.doctest',
     'sunpy.util.sphinx.generate',
     "sphinxext.opengraph",
-    'sphinx_panels',
+    'sphinx_design',
 ]
 
 # Set automodapi to generate files inside the generated directory
