@@ -9,57 +9,62 @@ import glob
 import pytest
 
 import astropy.units as u
-from astropy.utils.exceptions import AstropyUserWarning
 
 import sunpy.data.test
 from sunpy.map import Map
 from sunpy.map.sources.hinode import XRTMap
-from sunpy.util.exceptions import SunpyMetadataWarning
 
 
 @pytest.fixture
-def xrt():
+def xrt_map():
     path = sunpy.data.test.rootdir
     fitspath = glob.glob(os.path.join(path, "HinodeXRT.fits"))
-    with pytest.warns(AstropyUserWarning, match='File may have been truncated'):
-        return Map(fitspath)
+    return Map(fitspath)
 
 
-# XRT Tests
-def test_fitstoXRT(xrt):
+def test_fits_to_xrt(xrt_map):
     """Tests the creation of XRTMap using FITS."""
-    assert isinstance(xrt, XRTMap)
+    assert isinstance(xrt_map, XRTMap)
 
 
-def test_is_datasource_for(xrt):
+def test_is_datasource_for(xrt_map):
     """Test the is_datasource_for method of XRTMap.
     Note that header data to be provided as an argument
     can be a MetaDict object."""
-    assert xrt.is_datasource_for(xrt.data, xrt.meta)
+    assert xrt_map.is_datasource_for(xrt_map.data, xrt_map.meta)
 
 
-def test_observatory(xrt):
+def test_observatory(xrt_map):
     """Tests the observatory property of the XRTMap object."""
-    assert xrt.observatory == "Hinode"
+    assert xrt_map.observatory == "Hinode"
 
 
-def test_measurement(xrt):
+def test_measurement(xrt_map):
     """Tests the measurement property of the XRTMap object."""
-    measurement = xrt.filter_wheel1_measurements[5].replace("_", " ")
-    measurement += '-' + xrt.filter_wheel2_measurements[1].replace("_", " ")
-    assert xrt.measurement == measurement
+    assert xrt_map.measurement == 'Open-Al mesh'
 
 
-def test_wheel_measurements(xrt):
+def test_level_number(xrt_map):
+    assert xrt_map.processing_level == 0
+
+
+def test_heliographic_longitude(xrt_map):
+    assert u.allclose(xrt_map.heliographic_longitude, 0 * u.deg)
+
+
+def test_heliographic_latitude(xrt_map):
+    assert u.allclose(xrt_map.heliographic_latitude, 3.33047459 * u.deg)
+
+
+def test_wheel_measurements(xrt_map):
     """Tests the filter_wheel_measurements objects present
     in the XRTMap object."""
-    assert (xrt.filter_wheel1_measurements ==
+    assert (xrt_map.filter_wheel1_measurements ==
             ["Al_med", "Al_poly", "Be_med", "Be_thin", "C_poly", "Open"])
-    assert (xrt.filter_wheel2_measurements ==
+    assert (xrt_map.filter_wheel2_measurements ==
             ["Open", "Al_mesh", "Al_thick", "Be_thick", "Gband", "Ti_poly"])
 
 
-def test_wcs(xrt):
+def test_wcs(xrt_map):
     # Smoke test that WCS is valid and can transform from pixels to world coordinates
-    with pytest.warns(SunpyMetadataWarning, match='Missing metadata for observer'):
-        xrt.pixel_to_world(0*u.pix, 0*u.pix)
+    xrt_map.pixel_to_world(0*u.pix, 0*u.pix)
