@@ -3,10 +3,14 @@ This module provies `sunpy.timeseries.GenericTimeSeries` which all other
 `sunpy.timeseries.TimeSeries` classes inherit from.
 """
 import copy
+import html
+import textwrap
 from collections import OrderedDict
 from collections.abc import Iterable
 
 import pandas as pd
+from matplotlib.backend_bases import FigureCanvasBase
+from matplotlib.figure import Figure
 
 import astropy
 import astropy.units as u
@@ -18,6 +22,7 @@ from sunpy.timeseries import TimeSeriesMetaData
 from sunpy.util.datatype_factory_base import NoMatchError
 from sunpy.util.exceptions import warn_user
 from sunpy.util.metadata import MetaDict
+from sunpy.util.util import _figure_to_base64
 from sunpy.visualization import peek_show
 
 # define and register a new unit, needed for RHESSI
@@ -35,8 +40,8 @@ class GenericTimeSeries:
 
     Parameters
     ----------
-    data : `~pandas.DataFrame`
-        A `pandas.DataFrame` representing one or more fields as a function of time.
+    data : `~pandas.DataFrame` or `numpy.array`
+        A `pandas.DataFrame` or `numpy.array` representing one or more fields as a function of time.
     meta : `~sunpy.timeseries.metadata.TimeSeriesMetaData`, optional
         The metadata giving details about the time series data/instrument.
         Defaults to `None`.
@@ -97,13 +102,13 @@ class GenericTimeSeries:
         # Check metadata input
         if meta is None:
             # No meta given, so default
-            self.meta = TimeSeriesMetaData(MetaDict(), tr, list(self._data.columns.values))
+            self.meta = TimeSeriesMetaData(MetaDict(), tr, self.columns)
         elif isinstance(meta, (dict, OrderedDict, MetaDict)):
             # Given the values for metadata (dict) and infer timerange and colnames from the data
-            self.meta = TimeSeriesMetaData(meta, tr, list(self._data.columns.values))
+            self.meta = TimeSeriesMetaData(meta, tr, self.columns)
         elif isinstance(meta, tuple):
             # Given the values all in a tuple
-            self.meta = TimeSeriesMetaData(meta, tr, list(self._data.columns.values))
+            self.meta = TimeSeriesMetaData(meta, tr, self.columns)
         else:
             # Should have a list of 3-tuples giving a complex metadata list.
             self.meta = meta
@@ -113,11 +118,71 @@ class GenericTimeSeries:
         else:
             self.units = units
 
+        for col in self.columns:
+            if col not in self.units:
+                warn_user(f'Unknown units for {col}')
+                self.units[col] = u.dimensionless_unscaled
+
         # TODO: Fix this?
         # Validate input data
         # self._validate_meta()
         # self._validate_units()
 
+    def _text_summary(self):
+        start_time, end_time = self.time_range.start, self.time_range.end
+        center_time = self.time_range.center
+        duration = str(self.time_range.days.value) + " days"
+        columns = ", ".join(self.columns)
+
+        return textwrap.dedent(f"""\
+                   Start Time:\t\t {start_time}
+                   End Time:\t\t {end_time}
+                   Center Time:\t\t {center_time}
+                   Duration:\t\t {duration}
+                   Columns:\t\t {columns}""")
+
+    def __str__(self):
+        return f"{self.meta}\n{self._data.__repr__()}"
+
+    def __repr__(self):
+        return f"{object.__repr__(self)}\n{self}"
+
+    def _repr_html_(self):
+        """
+        Produce an HTML summary with plots for use in Jupyter notebooks.
+        """
+
+        # Convert the text repr to an HTML table
+        partial_html = self._text_summary().replace('\n', '</td></tr><tr><th>')\
+            .replace(':\t', '</th><td>')
+        text_to_table = textwrap.dedent(f"""\
+            <table style='text-align:left'>
+                <tr><th>{partial_html}</td></tr>
+            </table>""").replace('\n', '')
+
+        # Plot the image in pixel space
+        fig = Figure()
+        # Figure instances in matplotlib<3.1 do not create a canvas by default
+        if fig.canvas is None:
+            FigureCanvasBase(fig)
+        ax = fig.subplots()
+        self.plot(axes=ax)
+        img_src = _figure_to_base64(fig)
+
+        return textwrap.dedent(f"""\
+            <pre>{html.escape(object.__repr__(self))}</pre>
+            <table>
+                <tr>
+                    <td>{text_to_table}</td>
+                    <td>
+                        <div align=center>
+                           <img src='data:image/png;base64,{img_src}'
+                        />
+                        </div>
+                    </td>
+                </tr>
+            </table>""")
+
 # #### Attribute definitions #### #
 
     @property
@@ -329,7 +394,6 @@ class GenericTimeSeries:
         # Build similar TimeSeries object and sanatise metadata and units.
         object = self.__class__(truncated_data.sort_index(), truncated_meta, copy.copy(self.units))
         object._sanitize_metadata()
-        object._sanitize_units()
         return object
 
     def extract(self, column_name):
@@ -355,13 +419,13 @@ class GenericTimeSeries:
 
         # Extract column and remove empty rows
         data = self._data[[column_name]].dropna()
+        units = {column_name: self.units[column_name]}
 
         # Build generic TimeSeries object and sanatise metadata and units.
         object = GenericTimeSeries(data.sort_index(),
                                    TimeSeriesMetaData(copy.copy(self.meta.metadata)),
-                                   copy.copy(self.units))
+                                   units)
         object._sanitize_metadata()
-        object._sanitize_units()
         return object
 
     def concatenate(self, others, same_source=False, **kwargs):
@@ -438,6 +502,7 @@ class GenericTimeSeries:
         units.update(
             {k: v for unit in list(series.units for series in others) for k, v in unit.items()}
         )
+        units = {k: v for k, v in units.items() if k in data.columns}
 
         # If sources match then build similar TimeSeries.
         if all(self.__class__ == series.__class__ for series in others):
@@ -448,7 +513,6 @@ class GenericTimeSeries:
 
         # Sanatise metadata and units
         object._sanitize_metadata()
-        object._sanitize_units()
         return object
 
 # #### Plotting Methods #### #
@@ -568,30 +632,6 @@ class GenericTimeSeries:
 
         return result
 
-    def _sanitize_units(self, **kwargs):
-        """
-        Sanitizes the `collections.OrderedDict` used to store the units.
-
-        Primarily this method will:
-
-        * Remove entries that don't match up to a column.
-        * Add unitless entries for columns with no units defined.
-        * Re-arrange the order of the dictionary to match the columns.
-        """
-        # Populate unspecified units:
-        for column in set(self._data.columns.tolist()) - set(self.units.keys()):
-            # For all columns not present in the units dictionary.
-            self.units[column] = u.dimensionless_unscaled
-            warn_user(f"Unknown units for {column}.")
-
-        # Re-arrange so it's in the same order as the columns and removed unused.
-        units = OrderedDict()
-        for column in self._data.columns.tolist():
-            units.update({column: self.units[column]})
-
-        # Now use the amended units Ordered Dictionary
-        self.units = units
-
     def _sanitize_metadata(self, **kwargs):
         """
         Sanitizes the `~sunpy.timeseries.TimeSeriesMetaData`  used to store the
